colour_burn: Blend colours and palettes using colour burn mode

View source: R/colour-burn.R

colour_burnR Documentation

Blend colours and palettes using colour burn mode

Description

Darkens the destination colour to reflect the source by increasing contrast. Produces deep, saturated results.

Usage

colour_burn(...)

Arguments

...

Either one or two colour/palette arguments:

  • If one argument: the colour or palette is blended with itself

  • If two arguments: the first is blended with the second Each argument can be a character vector of colours or a ⁠scales::pal_*()⁠ function

Value

Character vector of blended colours or a blending function.

Examples

colour_burn("#FFA600FF", "#8991A1FF")

blends documentation built on May 4, 2026, 9:09 a.m.