overlay: Blend colours and palettes using overlay mode

View source: R/overlay.R

overlayR Documentation

Blend colours and palettes using overlay mode

Description

Combines multiply and screen depending on the lightness of the second colour. Values below 50% grey are multiplied (darkened); values above are screened (lightened).

Usage

overlay(...)

Arguments

...

Either one or two colour/palette arguments:

  • If one argument: the colour or palette is blended with itself

  • If two arguments: the first is blended with the second Each argument can be a character vector of colours or a ⁠scales::pal_*()⁠ function

Value

Character vector of blended colours or a blending function.

Examples

overlay("#FFA600FF", "#8991A1FF")

blends documentation built on May 4, 2026, 9:09 a.m.