Darkens the destination colour to reflect the source by increasing contrast.
Produces deep, saturated results.
Arguments
- ...
Either one or two colour/palette arguments:
Value
Character vector of blended colours or a blending function.
Examples
colour_burn("#FFA600FF", "#8991A1FF")
#> [1] "#895600FF"