| colour_burn | R Documentation |
Darkens the destination colour to reflect the source by increasing contrast. Produces deep, saturated results.
colour_burn(...)
... |
Either one or two colour/palette arguments:
|
Character vector of blended colours or a blending function.
colour_burn("#FFA600FF", "#8991A1FF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.