colour_dodge: Blend colours and palettes using colour dodge mode

View source: R/colour-dodge.R

colour_dodgeR Documentation

Blend colours and palettes using colour dodge mode

Description

Brightens the destination colour to reflect the source by decreasing contrast. Produces bright, washed-out results.

Usage

colour_dodge(...)

Arguments

...

Either one or two colour/palette arguments:

  • If one argument: the colour or palette is blended with itself

  • If two arguments: the first is blended with the second Each argument can be a character vector of colours or a ⁠scales::pal_*()⁠ function

Value

Character vector of blended colours or a blending function.

Examples

colour_dodge("#FFA600FF", "#8991A1FF")

blends documentation built on May 4, 2026, 9:09 a.m.