| colour_dodge | R Documentation |
Brightens the destination colour to reflect the source by decreasing contrast. Produces bright, washed-out results.
colour_dodge(...)
... |
Either one or two colour/palette arguments:
|
Character vector of blended colours or a blending function.
colour_dodge("#FFA600FF", "#8991A1FF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.