Darkens colours by selecting the darker of two colour values for each RGB
channel. Useful for creating shadows or combining dark elements.
Arguments
- ...
Either one or two colour/palette arguments:
Value
Character vector of blended colours or a blending function.
Examples
darken("#FFA600FF", "#8991A1FF")
#> [1] "#899100FF"