| darken | R Documentation |
Darkens colours by selecting the darker of two colour values for each RGB channel. Useful for creating shadows or combining dark elements.
darken(...)
... |
Either one or two colour/palette arguments:
|
Character vector of blended colours or a blending function.
darken("#FFA600FF", "#8991A1FF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.