Combines multiply and screen depending on the lightness of the first colour.
Like overlay but the first colour controls whether darkening or lightening
is applied.
Arguments
- ...
Either one or two colour/palette arguments:
Value
Character vector of blended colours or a blending function.
Examples
hard_light("#FFA600FF", "#8991A1FF")
#> [1] "#FFB200FF"