| hard_light | R Documentation |
Combines multiply and screen depending on the lightness of the first colour. Like overlay but the first colour controls whether darkening or lightening is applied.
hard_light(...)
... |
Either one or two colour/palette arguments:
|
Character vector of blended colours or a blending function.
hard_light("#FFA600FF", "#8991A1FF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.