Lightens colours by selecting the lighter of two colour values for each RGB channel. Useful for creating highlights or combining light elements.
Arguments
- ...
Either one or two colour/palette arguments:
If one argument: the colour or palette is blended with itself
If two arguments: the first is blended with the second Each argument can be a character vector of colours or a
scales::pal_*()function.
Recycling for direct colour vectors follows
vctrssemantics: inputs must either have the same size, or one input must have size 1.