Lightens colours by selecting the lighter of two colour values for each RGB
channel. Useful for creating highlights or combining light elements.
Arguments
- ...
Either one or two colour/palette arguments:
Value
Character vector of blended colours or a blending function.
Examples
lighten("#FFA600FF", "#8991A1FF")
#> [1] "#FFA6A1FF"