| lighten | R Documentation |
Lightens colours by selecting the lighter of two colour values for each RGB channel. Useful for creating highlights or combining light elements.
lighten(...)
... |
Either one or two colour/palette arguments:
|
Character vector of blended colours or a blending function.
lighten("#FFA600FF", "#8991A1FF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.