Combines multiply and screen depending on the lightness of the second colour.
Values below 50% grey are multiplied (darkened); values above are screened
(lightened).
Arguments
- ...
Either one or two colour/palette arguments:
Value
Character vector of blended colours or a blending function.
Examples
overlay("#FFA600FF", "#8991A1FF")
#> [1] "#FFB243FF"