| overlay | R Documentation |
Combines multiply and screen depending on the lightness of the second colour. Values below 50% grey are multiplied (darkened); values above are screened (lightened).
overlay(...)
... |
Either one or two colour/palette arguments:
|
Character vector of blended colours or a blending function.
overlay("#FFA600FF", "#8991A1FF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.