| screen | R Documentation |
Lightens colours by inverting, multiplying, then inverting again. Creates brighter results. Useful for creating highlights, lightening backgrounds, or adding luminosity.
screen(...)
... |
Either one or two colour/palette arguments:
|
Character vector of blended colours or a blending function.
screen("#2C2C2C", "#808080")
screen("#4A4A4A")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.