| soft_light | R Documentation |
A softer version of hard light. Darkens or lightens depending on the first colour, but with a gentler effect than hard light.
soft_light(...)
... |
Either one or two colour/palette arguments:
|
Character vector of blended colours or a blending function.
soft_light("#FFA600FF", "#8991A1FF")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.